# coding=utf-8
from __future__ import unicode_literals

from .. import Provider as LoremProvider


class Provider(LoremProvider):
    word_connector = ''
    sentence_punctuation = '。'
    word_list = (
        u'コミュニティ',
        u'隠す',
        u'葉',
        u'陶器',
        u'錯覚',
        u'バーゲン',
        u'リニア',
        u'コーラス',
        u'仕上げ',
        u'叔父',
        u'移動',
        u'差別する',
        u'極端な',
        u'数字',
        u'テント',
        u'必要',
        u'主人',
        u'電池',
        u'ソース',
        u'野球',
        u'ストレージ',
        u'スキーム',
        u'暖かい',
        u'ささやき',
        u'器官',
        u'トリビュート',
        u'同行',
        u'ジャム',
        u'パン',
        u'索引',
        u'トス',
        u'織る',
        u'パーセント',
        u'拡張',
        u'教授',
        u'バスケット',
        u'創傷',
        u'フレーム',
        u'明らかにする',
        u'フェミニスト',
        u'発生する',
        u'怒り',
        u'ボトル',
        u'狐',
        u'柔らかい',
        u'リフト',
        u'バス',
        u'雪',
        u'画面',
        u'パイオニア',
        u'マリン',
        u'ダイヤモンド',
        u'普通の',
        u'意図',
        u'ヘア',
        u'日曜日',
        u'プラスチック',
        u'衝突',
        u'評議会',
        u'主婦',
        u'保証金',
        u'動物',
        u'参加する',
        u'教会',
        u'コミュニケーション',
        u'憲法',
        u'本質的な',
        u'探査',
        u'呼ぶ',
        u'供給',
        u'スペル',
        u'再現する',
        u'合計',
        u'ダッシュ',
        u'擁する',
        u'知覚',
        u'シェービング',
        u'コンペ',
        u'オークション',
        u'細かい',
        u'ニュース',
        u'癌',
        u'トーン',
        u'チーズ',
        u'反射',
        u'ブランチ',
        u'コピー',
        u'状況',
        u'スマッシュ',
        u'式',
        u'協力',
        u'管理する',
        u'文言',
        u'編組',
        u'ジャーナル',
        u'腐った',
        u'見落とす',
        u'ハードウェア',
        u'ピック',
        u'感謝する',
        u'楽しんで',
        u'人形',
        u'建築',
        u'見出し',
        u'タワー',
        u'ホイール',
        u'省略',
        u'ログ',
        u'助けて',
        u'不自然な',
        u'出演者',
        u'転倒',
        u'運',
        u'障害',
        u'クルー',
        u'追放する',
        u'月',
        u'カレッジ',
        u'緩む',
        u'分割',
        u'欠乏',
        u'通行料金',
        u'電話',
        u'狭い',
        u'中央',
        u'埋め込む',
        u'革新',
        u'ブレーキ',
        u'コーナー',
        u'溝',
        u'脊椎',
        u'ブラケット',
        u'戦略的',
        u'尿',
        u'血まみれの',
        u'尊敬する',
        u'催眠術',
        u'アクセルペダル',
        u'厳しい',
        u'サンプル',
        u'奨励します',
        u'指名',
        u'クール',
        u'クロス',
        u'ヒール',
        u'敵対的な',
        u'近代化する',
        u'部隊',
        u'目的',
        u'保持する',
        u'中世',
        u'デッド',
        u'ノート',
        u'デフォルト',
        u'犯罪者',
        u'キャビン',
        u'副',
        u'改善',
        u'職人',
        u'シュガー',
        u'花嫁',
        u'倫理',
        u'偏差',
        u'販売',
        u'軸',
        u'サラダ',
        u'品質',
        u'風景',
        u'虐待',
        u'立派な',
        u'ベルベット',
        u'ハンマー',
        u'キャビネット',
        u'トレーナー',
        u'リハビリ',
        u'サワー',
        u'連続',
        u'学生',
        u'高い',
        u'賞賛する',
        u'行進',
        u'ダニ',
        u'証言する',
        u'符号',
        u'バナー',
        u'バケツ',
        u'カラム',
        u'装置',
        u'ヒット',
        u'敵',
        u'トースト',
        u'試してみる',
        u'大統領',
        u'屋根裏',
        u'メニュー',
        u'残る',
        u'リンク',
        u'舗装',
        u'インチ',
        u'特徴',
        u'は',
        u'持つ',
        u'持っていました',
        u'あった',
        u'〜',
        u'ない',
        u'今',
        u'今日',
        u'持ってる',
        u'午前',
        u'私',
        u'君は',
        u'彼',
        u'彼女',
        u'それ',
        u'自体',
        u'あなた自身',
        u'じぶんの',
        u'鉱山',
    )
